@@ -56,10 +56,10 @@ def make_logger(
 
     Parameters
     ----------
-    parser : :class:`configparser.ConfigParser`
+    parser
         A parser containing any .cfg files in use.
 
-    verbosity : :class:`str`
+    verbosity
         The verbosity level of the logger.
 
     Returns
@@ -106,7 +106,7 @@ def parse_theme(parser: configparser.ConfigParser) -> Theme:
 
     Parameters
     ----------
-    parser : :class:`configparser.ConfigParser`
+    parser
         A parser containing any .cfg files in use.
 
     Returns
@@ -148,9 +148,12 @@ def set_file_logger(scene_name: str, module_name: str, log_dir: Path) -> None:
 
     Parameters
     ----------
-    config : :class:`ManimConfig`
-        The global config, used to determine the log file path.
-
+    scene_name
+        The name of the scene, used in the name of the log file.
+    module_name
+        The name of the module, used in the name of the log file.
+    log_dir
+        Path to the folder where log files are stored.
     """
     # Note: The log file name will be
     # <name_of_animation_file>_<name_of_scene>.log, gotten from config.  So it
