@@ -14,7 +14,7 @@ __all__ = [
     "RightAngle",
 ]
 
-from typing import Sequence
+from typing import Any, Sequence
 
 import numpy as np
 from colour import Color
@@ -28,6 +28,7 @@ from manim.mobject.opengl.opengl_compatibility import ConvertToOpenGL
 from manim.mobject.opengl.opengl_mobject import OpenGLMobject
 from manim.mobject.types.vectorized_mobject import DashedVMobject, VGroup, VMobject
 from manim.utils.color import *
+from manim.utils.color import Colors
 from manim.utils.space_ops import angle_of_vector, line_intersection, normalize
 
 
@@ -190,13 +191,13 @@ class DashedLine(Line):
 
     Parameters
     ----------
-    args : Any
+    args
         Arguments to be passed to :class:`Line`
-    dash_length : :class:`float`, optional
+    dash_length
         The length of each individual dash of the line.
-    dashed_ratio : :class:`float`, optional
+    dashed_ratio
         The ratio of dash space to empty space. Range of 0-1.
-    kwargs : Any
+    kwargs
         Additional arguments to be passed to :class:`Line`
 
 
@@ -221,9 +222,9 @@ class DashedLine(Line):
 
     def __init__(
         self,
-        *args,
-        dash_length=DEFAULT_DASH_LENGTH,
-        dashed_ratio=0.5,
+        *args: Any,
+        dash_length: float = DEFAULT_DASH_LENGTH,
+        dashed_ratio: float = 0.5,
         **kwargs,
     ):
         self.dash_length = dash_length
@@ -318,15 +319,15 @@ class TangentLine(Line):
 
     Parameters
     ----------
-    vmob : :class:`~.VMobject`
+    vmob
         The VMobject on which the tangent line is drawn.
-    alpha : :class:`float`
+    alpha
         How far along the shape that the line will be constructed. range: 0-1.
-    length : :class:`float`, optional
+    length
         Length of the tangent line.
-    d_alpha: :class:`float`, optional
+    d_alpha
         The ``dx`` value
-    kwargs : Any
+    kwargs
         Additional arguments to be passed to :class:`Line`
 
 
@@ -346,7 +347,14 @@ class TangentLine(Line):
                 self.add(circle, line_1, line_2)
     """
 
-    def __init__(self, vmob, alpha, length=1, d_alpha=1e-6, **kwargs):
+    def __init__(
+        self,
+        vmob: VMobject,
+        alpha: float,
+        length: float = 1,
+        d_alpha: float = 1e-6,
+        **kwargs,
+    ):
         self.length = length
         self.d_alpha = d_alpha
         da = self.d_alpha
@@ -363,11 +371,11 @@ class Elbow(VMobject, metaclass=ConvertToOpenGL):
 
     Parameters
     ----------
-    width : :class:`float`, optional
+    width
         The length of the elbow's sides.
-    angle : :class:`float`, optional
+    angle
         The rotation of the elbow.
-    kwargs : Any
+    kwargs
         Additional arguments to be passed to :class:`~.VMobject`
 
     .. seealso::
@@ -388,7 +396,7 @@ class Elbow(VMobject, metaclass=ConvertToOpenGL):
                 self.add(elbow_group)
     """
 
-    def __init__(self, width=0.2, angle=0, **kwargs):
+    def __init__(self, width: float = 0.2, angle: float = 0, **kwargs):
         self.angle = angle
         super().__init__(**kwargs)
         self.set_points_as_corners([UP, UP + RIGHT, RIGHT])
@@ -401,17 +409,17 @@ class Arrow(Line):
 
     Parameters
     ----------
-    args : Any
+    args
         Arguments to be passed to :class:`Line`.
-    stroke_width : :class:`float`, optional
+    stroke_width
         The thickness of the arrow. Influenced by :attr:`max_stroke_width_to_length_ratio`.
-    buff : :class:`float`, optional
+    buff
         The distance of the arrow from its start and end points.
-    max_tip_length_to_length_ratio : :class:`float`, optional
+    max_tip_length_to_length_ratio
         :attr:`tip_length` scales with the length of the arrow. Increasing this ratio raises the max value of :attr:`tip_length`.
-    max_stroke_width_to_length_ratio : :class:`float`, optional
+    max_stroke_width_to_length_ratio
         :attr:`stroke_width` scales with the length of the arrow. Increasing this ratio ratios the max value of :attr:`stroke_width`.
-    kwargs : Any
+    kwargs
         Additional arguments to be passed to :class:`Line`.
 
 
@@ -486,11 +494,11 @@ class Arrow(Line):
 
     def __init__(
         self,
-        *args,
-        stroke_width=6,
-        buff=MED_SMALL_BUFF,
-        max_tip_length_to_length_ratio=0.25,
-        max_stroke_width_to_length_ratio=5,
+        *args: Any,
+        stroke_width: float = 6,
+        buff: float = MED_SMALL_BUFF,
+        max_tip_length_to_length_ratio: float = 0.25,
+        max_stroke_width_to_length_ratio: float = 5,
         **kwargs,
     ):
         self.max_tip_length_to_length_ratio = max_tip_length_to_length_ratio
@@ -590,7 +598,7 @@ class Arrow(Line):
     def _set_stroke_width_from_length(self):
         """Sets stroke width based on length."""
         max_ratio = self.max_stroke_width_to_length_ratio
-        if config.renderer == "opengl":
+        if config.renderer == RendererType.OPENGL:
             self.set_stroke(
                 width=min(self.initial_stroke_width, max_ratio * self.get_length()),
                 recurse=False,
@@ -608,11 +616,11 @@ class Vector(Arrow):
 
     Parameters
     ----------
-    direction : Union[:class:`list`, :class:`numpy.ndarray`]
+    direction
         The direction of the arrow.
-    buff : :class:`float`
+    buff
          The distance of the vector from its endpoints.
-    kwargs : Any
+    kwargs
         Additional arguments to be passed to :class:`Arrow`
 
     Examples
@@ -628,7 +636,7 @@ class Vector(Arrow):
                 self.add(plane, vector_1, vector_2)
     """
 
-    def __init__(self, direction=RIGHT, buff=0, **kwargs):
+    def __init__(self, direction: list | np.ndarray = RIGHT, buff: float = 0, **kwargs):
         self.buff = buff
         if len(direction) == 2:
             direction = np.hstack([direction, 0])
@@ -704,9 +712,9 @@ class DoubleArrow(Arrow):
 
     Parameters
     ----------
-    args : Any
+    args
         Arguments to be passed to :class:`Arrow`
-    kwargs : Any
+    kwargs
         Additional arguments to be passed to :class:`Arrow`
 
 
@@ -744,7 +752,7 @@ class DoubleArrow(Arrow):
                 self.add(box, d1, d2, d3)
     """
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args: Any, **kwargs):
         if "tip_shape_end" in kwargs:
             kwargs["tip_shape"] = kwargs.pop("tip_shape_end")
         tip_shape_start = kwargs.pop("tip_shape_start", ArrowTriangleFilledTip)
@@ -763,7 +771,7 @@ class Angle(VMobject, metaclass=ConvertToOpenGL):
         The second line.
     radius :
         The radius of the :class:`Arc`.
-    quadrant : Sequence[:class:`int`]
+    quadrant
         A sequence of two :class:`int` numbers determining which of the 4 quadrants should be used.
         The first value indicates whether to anchor the arc on the first line closer to the end point (1)
         or start point (-1), and the second value functions similarly for the
@@ -773,16 +781,16 @@ class Angle(VMobject, metaclass=ConvertToOpenGL):
         Toggles between the two possible angles defined by two points and an arc center. If set to
         False (default), the arc will always go counterclockwise from the point on line1 until
         the point on line2 is reached. If set to True, the angle will go clockwise from line1 to line2.
-    dot : :class:`bool`
+    dot
         Allows for a :class:`Dot` in the arc. Mainly used as an convention to indicate a right angle.
         The dot can be customized in the next three parameters.
-    dot_radius : :class:`float`
+    dot_radius
         The radius of the :class:`Dot`. If not specified otherwise, this radius will be 1/10 of the arc radius.
-    dot_distance : :class:`float`
+    dot_distance
         Relative distance from the center to the arc: 0 puts the dot in the center and 1 on the arc itself.
-    dot_color : :class:`~.Colors`
+    dot_color
         The color of the :class:`Dot`.
-    elbow : :class:`bool`
+    elbow
         Produces an elbow-type mobject indicating a right angle, see :class:`RightAngle` for more information
         and a shorthand.
     **kwargs
@@ -866,13 +874,13 @@ class Angle(VMobject, metaclass=ConvertToOpenGL):
         line1: Line,
         line2: Line,
         radius: float = None,
-        quadrant=(1, 1),
+        quadrant: Sequence[int] = (1, 1),
         other_angle: bool = False,
-        dot=False,
-        dot_radius=None,
-        dot_distance=0.55,
-        dot_color=WHITE,
-        elbow=False,
+        dot: bool = False,
+        dot_radius: float | None = None,
+        dot_distance: float = 0.55,
+        dot_color: Colors = WHITE,
+        elbow: bool = False,
         **kwargs,
     ):
         super().__init__(**kwargs)
