@@ -8,6 +8,9 @@ __all__ = [
     "ArrowCircleTip",
     "ArrowSquareTip",
     "ArrowSquareFilledTip",
+    "ArrowTriangleTip",
+    "ArrowTriangleFilledTip",
+    "StealthTip",
 ]
 
 import numpy as np
@@ -30,6 +33,7 @@ class ArrowTip(VMobject, metaclass=ConvertToOpenGL):
         :class:`ArrowCircleFilledTip`
         :class:`ArrowSquareTip`
         :class:`ArrowSquareFilledTip`
+        :class:`StealthTip`
 
     Examples
     --------
@@ -177,6 +181,47 @@ class ArrowTip(VMobject, metaclass=ConvertToOpenGL):
         return np.linalg.norm(self.vector)
 
 
+class StealthTip(ArrowTip):
+    r"""'Stealth' fighter / kite arrow shape.
+
+    Naming is inspired by the corresponding
+    `TikZ arrow shape <https://tikz.dev/tikz-arrows#sec-16.3>`__.
+    """
+
+    def __init__(
+        self,
+        fill_opacity=1,
+        stroke_width=3,
+        length=DEFAULT_ARROW_TIP_LENGTH / 2,
+        start_angle=PI,
+        **kwargs,
+    ):
+        self.start_angle = start_angle
+        VMobject.__init__(
+            self, fill_opacity=fill_opacity, stroke_width=stroke_width, **kwargs
+        )
+        self.set_points_as_corners(
+            [
+                [2, 0, 0],  # tip
+                [-1.2, 1.6, 0],
+                [0, 0, 0],  # base
+                [-1.2, -1.6, 0],
+                [2, 0, 0],  # close path, back to tip
+            ]
+        )
+        self.scale(length / self.length)
+
+    @property
+    def length(self):
+        """The length of the arrow tip.
+
+        In this case, the length is computed as the height of
+        the triangle encompassing the stealth tip (otherwise,
+        the tip is scaled too large).
+        """
+        return np.linalg.norm(self.vector) * 1.6
+
+
 class ArrowTriangleTip(ArrowTip, Triangle):
     r"""Triangular arrow tip."""
 
