@@ -727,7 +727,7 @@ class SceneFileWriter:
     def write_subcaption_file(self):
         """Writes the subcaption file."""
         subcaption_file = Path(config.output_file).with_suffix(".srt")
-        subcaption_file.write_text(srt.compose(self.subcaptions))
+        subcaption_file.write_text(srt.compose(self.subcaptions), encoding="utf-8")
         logger.info(f"Subcaption file has been written as {subcaption_file}")
 
     def print_file_ready_message(self, file_path):
