@@ -261,21 +261,16 @@ def resize_array(nparray: np.ndarray, length: int) -> np.ndarray:
     --------
     Normal usage::
 
-        nparray = np.array([[1, 2],
-                            [3, 4]])
-
-        resize_array(nparray, 1)
-        # np.array([[1, 2]])
-
-        resize_array(nparray, 3)
-        # np.array([[1, 2],
-        #           [3, 4],
-        #           [1, 2]])
-
-        nparray = np.array([[[1, 2],[3, 4]]])
-        resize_array(nparray, 2)
-        # np.array([[[1, 2], [3, 4]],
-        #           [[1, 2], [3, 4]]])
+        >>> points = np.array([[1, 2], [3, 4]])
+        >>> resize_array(points, 1)
+        array([[1, 2]])
+        >>> resize_array(points, 3)
+        array([[1, 2],
+               [3, 4],
+               [1, 2]])
+        >>> resize_array(points, 2)
+        array([[1, 2],
+               [3, 4]])
     """
     if len(nparray) == length:
         return nparray
@@ -426,3 +421,17 @@ def uniq_chain(*args: Iterable) -> Generator:
             continue
         unique_items.add(x)
         yield x
+
+
+def hash_obj(obj: object) -> int:
+    """Determines a hash, even of potentially mutable objects."""
+    if isinstance(obj, dict):
+        return hash(tuple(sorted((hash_obj(k), hash_obj(v)) for k, v in obj.items())))
+
+    if isinstance(obj, set):
+        return hash(tuple(sorted(hash_obj(e) for e in obj)))
+
+    if isinstance(obj, (tuple, list)):
+        return hash(tuple(hash_obj(e) for e in obj))
+
+    return hash(obj)
