@@ -244,7 +244,8 @@ def convert_to_svg(dvi_file: Path, extension: str, page: int = 1):
             f"Your installation does not support converting {dvi_file.suffix} files to SVG."
             f" Consider updating dvisvgm to at least version 2.4."
             f" If this does not solve the problem, please refer to our troubleshooting guide at:"
-            f" https://docs.manim.community/en/stable/installation/troubleshooting.html",
+            f" https://docs.manim.community/en/stable/faq/general.html#my-installation-"
+            f"does-not-support-converting-pdf-to-svg-help",
         )
 
     return result
